@@ -1,26 +1,15 @@
-/***************************************************************************
- *   Copyright  2010 Johannes Loehnert <loehnert.kde@gmx.de>
- *
- *   This program is free software; you can redistribute it and/or
- *   modify it under the terms of the GNU General Public
- *   License as published by the Free Software Foundation; either
- *   version 2 of the License, or (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2010 Johannes Loehnert <loehnert.kde@gmx.de>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef PALAPELISLICERS_GOLDBERG_ENGINE_H
 #define PALAPELISLICERS_GOLDBERG_ENGINE_H
 
-#include "../../libpala/slicerjob.h"
+#include <Pala/SlicerJob>
 #include <QPainterPath>
+
 struct GBClassicPlugParams {
     bool flipped;
     bool is_plugless;
@@ -81,7 +70,7 @@ class GoldbergEngine {
         // checks if candidate intersects with an already set border.
         // If *offenders is given and the plugs intersect, a reference to the "other" border is added to the list.
         // If any plug is not rendered yet, this is done beforehands.
-        bool plugsIntersect(GBClassicPlugParams &candidate, GBClassicPlugParams &other, QList<GBClassicPlugParams*>* offenders=NULL);
+        bool plugsIntersect(GBClassicPlugParams &candidate, GBClassicPlugParams &other, QList<GBClassicPlugParams*>* offenders = nullptr);
         // checks if candidate is out of bounds (image frame).
         // If candidate is not rendered yet, this is done beforehands.
         bool plugOutOfBounds(GBClassicPlugParams &candidate);
